import {
  Http, IDictionary, Loader,
} from '@zeedhi/core';
import {
  ApexChart,
} from '@zeedhi/common';

export class DashboardSupervisorController {
  public hierarquiasController = Loader.getInstance('HierarquiasController');

  public setFiltroUltimasTarefas({ component }: any) {
    this.hierarquiasController.mountHierarchyUsersArray().then((response: IDictionary) => {
      component.datasource.setFilter({
        HIERARQUIA: response,
      });
    });
  }

  // responsavel por pegar os dados do chard Tarefas Realizadas e plotar as informações
  public async getDadosChartTarefasRealizadas({ component }:{ component: ApexChart }) {
    const hierarchyUsersList = await this.hierarquiasController.mountHierarchyUsersArray();

    Http.post('/getDadosChartTarefas', { param: hierarchyUsersList }).then((response: IDictionary) => {
      const { dados } = response.data.dataset;
      if (dados.length) {
        dados.forEach((data: IDictionary) => {
          component.options.labels.push(data.NMATIVIDADE);
          (component.series as any[]).push(data.QUANTIDADE);
          component.options.colors.push(data.DSCORIDATIVIDADE);
        });
      } else {
        component.options.labels.push('Não há dados disponíveis');
        (component.series as any[]).push(1);
        component.options.colors.push('#57737a');
      }
    });
  }

  // responsavel por pegar os dados do chard Não Conformidades e plotar as informações
  public async getDadosChartNaoConformidade({ component }:{ component: ApexChart }) {
    const hierarchyUsersList = await this.hierarquiasController.mountHierarchyUsersArray();

    Http.post('/getDadosChartNaoConformidades', { param: hierarchyUsersList }).then((response: IDictionary) => {
      const { dados } = response.data.dataset;
      if (dados.length) {
        dados.forEach((dadosGraf: IDictionary) => {
          (component.series as any[]).push({
            name: dadosGraf.NMATIVIDADE,
            data: [dadosGraf.QUANTIDADE],
          });
          component.options.colors.push(dadosGraf.DSCORIDATIVIDADE);
        });
      } else {
        (component.series as any[]).push({
          name: 'Nenhum dado disponível',
          data: [100],
        });
        component.options.colors.push('#57737a');
      }
    });
  }

  // responsavel por pegar os dados do chard Progresso Diário e plotar as informações
  public async dailyProgressChart({ component }:{ component: ApexChart }) {
    const hierarchyUsersList = await this.hierarquiasController.mountHierarchyUsersArray();

    Http.get(`/getDadosChartProgressoDiario?hierarchyUsersList=${hierarchyUsersList}`).then((response: IDictionary) => {
      const { dados } = response.data.dataset;
      if (dados.length) {
        dados.forEach((dadosGraf: IDictionary) => {
          (component.series as any[]).push({
            name: dadosGraf.NMATIVIDADE,
            data: [`${dadosGraf.PORCENTAGEM}%`],
          });
          component.options.colors.push(dadosGraf.DSCORIDATIVIDADE);
        });
      } else {
        (component.series as any[]).push({
          name: 'Nenhum dado disponível',
          data: [100],
        });
        component.options.colors.push('#57737a');
      }
    });
  }
}
